#
# spec file for package crudini
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           crudini
Version:        0.9.5
Release:        1.4
Summary:        A utility for manipulating ini files
License:        GPL-2.0-only
Group:          System/Base
URL:            https://github.com/pixelb/crudini
Source0:        https://github.com/pixelb/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-iniparse
Requires:       python3-iniparse
BuildArch:      noarch

%description
A utility for easily handling ini files from the command line and shell
scripts.

%prep
%setup -q

sed -i 's/env python/python3/' crudini.py

%build

%install
install -m 0755 -D %{name}.py %{buildroot}%{_bindir}/%{name}
install -m 0644 -D %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

%check
pushd tests
LC_ALL=en_US.utf8 ./test.sh
popd

%files
%license COPYING
%doc README.md EXAMPLES TODO NEWS example.ini
%{_bindir}/crudini
%{_mandir}/man1/*

%changelog
* Thu Nov 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.5:
  * Support for multiple --set and --del, or --get operations,
    allowing for more efficient and atomic updates to multiple
    parameters.
  * Support indented ini files with --ini-options=ignoreindent.
    Indentation is ignored (and maintained) in the ini file.
  * --format=sh will now attempt to output a whole ini file in
    sh format.
    Previously it would have only printed the section names.
* Mon Mar 13 2023 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.9.4
  * Fix updating of flag only parameters so they don't have '='
    or '=crudini_no_arg' added added on update
  * Handle closed stdin/stdout gracefully, without giving errors
  * Windows line endings are maintained
  * Lists can be delimited with arbitrary whitespace with --list-sep=
  * Support for unspaced "name=val" format with --ini-options=nospace
* Wed May 13 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to 0.9.3:
  * Python 3 support
  * Fix regression with windows line endings
- Run spec-cleaner
- Add BuildArch noarch
- Run crudini test script
- Add manpage
* Thu Aug 24 2017 tbechtold@suse.com
- update to 0.9:
  * Write errors to stdout are diagnosed correctly and consistently.
  * Replacing symlinks now replaces the target rather than the symlink itself.
  * The case of parameters is maintained with --get.
  * Single token parameters (without equals) are now supported,
    which are used in mysql config for example.
- Drop 3c52bd938975f7c5b32d7009f109ccbd2328c16d.patch . Applied upstream.
* Thu Dec  8 2016 tbechtold@suse.com
- update to 0.8:
  * maint: improve documentation for fsync() calls
  * use sha256 rather than md5 to checksum file contents
  * maint: remove stale comment
  * document --help and --version
  * fix spelling in --help and man page
  * fix processing of lines starting with "rem"
  * bump version for release
- add 3c52bd938975f7c5b32d7009f109ccbd2328c16d.patch .
  Fixes symlink handling when writing linked files.
* Thu Feb 18 2016 aplanas@suse.com
- update to 0.7 (bsc#966695):
  Bug fixes
  * Separate locking files are no longer used which avoids deadlock in
    cases where the system is stopped in the small window where these
    files exist.
  * Files are now synced after writing for better Durability.
  * crudini no longer removes a blank line from the start of a file
    which has no sections, or options outside a section. [bug
    introduced in version 0.5]
  Bug fixes
  * Lock files are cleaned up robustly. Previously there was a race
    condition resulting in blocked subsequent edits, due to a
    lingering lock file.
  * --del will ignore requests to delete a parameter in a non-existing
    section (unless --existing is used). Previously it failed citing
    the missing section.
  New features
  * The --existing option takes parameters to give more control over
    what needs to pre-exist. So you can specify for example that a
    file needs to exist, but any items within it are created as
    needed.
  * A new --verbose option was added to indicate on stderr wether the
    request resulted in a config change or not. This can be used to
    determine whether to restart programs etc.
  Changes in behavior
  * Files are created by default if missing, unless --existing is
    specified.
  Improvements
  * Protections against creating unparseable ini files were added.
  * stdin can be parsed just as with normal files.
  * File writes are avoided if there are no changes to the config.
* Fri Oct 10 2014 dmueller@suse.com
- update to 0.4:
  * add --format=lines to support line by line processing
  * doc: tweak readme to mention --format=lines
  * Declare encoding to avoid fatal error
  * fix duplicate DEFAULT section header being output
  * ensure edited ini file contents are always complete
  * split out --options from synopsis
  * send --help to stdout
  * provide alternative --rewrite file editing option
  * provide --output option to allow redirecting output
  * use only the base 'crudini' name in --help
  * ensure writes to the edited ini are never lost
  * add a new --list option to update a list of values
  * honor case when merging new parameters
* Fri Sep 27 2013 dmueller@suse.com
- Initial package (0.3)
